Package: Mergeomics
Type: Package
Title: Integrative network analysis of omics data
Version: 1.40.0
Date: 2016-01-04
Author: Ville-Petteri Makinen, Le Shu, Yuqi Zhao, Zeyneb Kurt, Bin Zhang,
    Xia Yang
Maintainer: Zeyneb Kurt <zeynebkurt@gmail.com>
Description: The Mergeomics pipeline serves as a flexible framework for 
    integrating multidimensional omics-disease associations, functional
    genomics,  canonical pathways and gene-gene interaction networks to
    generate mechanistic hypotheses. It includes two main parts,
    1) Marker set enrichment analysis (MSEA); 
    2) Weighted Key Driver Analysis (wKDA). 
biocViews: Software
Suggests: RUnit, BiocGenerics
License: GPL (>= 2)
Depends: R (>= 3.0.1)
Packaged: 2026-04-28 23:10:59 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/Mergeomics
git_branch: RELEASE_3_23
git_last_commit: 115b529
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
